You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by er...@apache.org on 2012/02/14 17:18:50 UTC

svn commit: r1244107 [11/18] - in /commons/proper/math/trunk: ./ src/main/java/org/apache/commons/math/ src/main/java/org/apache/commons/math3/ src/main/java/org/apache/commons/math3/analysis/ src/main/java/org/apache/commons/math3/analysis/function/ s...

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/Well44497b.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/Well44497b.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/Well44497b.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/Well44497b.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.random;
+package org.apache.commons.math3.random;
 
 
 /** This class implements the WELL44497b pseudo-random number generator

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/Well512a.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/Well512a.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/Well512a.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/Well512a.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.random;
+package org.apache.commons.math3.random;
 
 
 /** This class implements the WELL512a pseudo-random number generator

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Beta.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Beta.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.special;
+package org.apache.commons.math3.special;
 
-import org.apache.commons.math.util.ContinuedFraction;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.ContinuedFraction;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This is a utility class that provides computation methods related to the
@@ -43,7 +43,7 @@ public class Beta {
      * @param a Parameter {@code a}.
      * @param b Parameter {@code b}.
      * @return the regularized beta function I(x, a, b).
-     * @throws org.apache.commons.math.exception.MaxCountExceededException
+     * @throws org.apache.commons.math3.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      */
     public static double regularizedBeta(double x, double a, double b) {
@@ -62,7 +62,7 @@ public class Beta {
      * series is less than epsilon the approximation ceases to calculate
      * further elements in the series.
      * @return the regularized beta function I(x, a, b)
-     * @throws org.apache.commons.math.exception.MaxCountExceededException
+     * @throws org.apache.commons.math3.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      */
     public static double regularizedBeta(double x,
@@ -79,7 +79,7 @@ public class Beta {
      * @param b Parameter {@code b}.
      * @param maxIterations Maximum number of "iterations" to complete.
      * @return the regularized beta function I(x, a, b)
-     * @throws org.apache.commons.math.exception.MaxCountExceededException
+     * @throws org.apache.commons.math3.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      */
     public static double regularizedBeta(double x,
@@ -109,7 +109,7 @@ public class Beta {
      * further elements in the series.
      * @param maxIterations Maximum number of "iterations" to complete.
      * @return the regularized beta function I(x, a, b)
-     * @throws org.apache.commons.math.exception.MaxCountExceededException
+     * @throws org.apache.commons.math3.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      */
     public static double regularizedBeta(double x,

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Erf.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Erf.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Erf.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Erf.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.special;
+package org.apache.commons.math3.special;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This is a utility class that provides computation methods related to the
@@ -59,7 +59,7 @@ public class Erf {
      *
      * @param x the value.
      * @return the error function erf(x)
-     * @throws org.apache.commons.math.exception.MaxCountExceededException
+     * @throws org.apache.commons.math3.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      * @see Gamma#regularizedGammaP(double, double, double, int)
      */
@@ -89,7 +89,7 @@ public class Erf {
      *
      * @param x the value
      * @return the complementary error function erfc(x)
-     * @throws org.apache.commons.math.exception.MaxCountExceededException
+     * @throws org.apache.commons.math3.exception.MaxCountExceededException
      * if the algorithm fails to converge.
      * @see Gamma#regularizedGammaQ(double, double, double, int)
      * @since 2.2

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Gamma.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Gamma.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Gamma.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Gamma.java Tue Feb 14 16:17:55 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.special;
+package org.apache.commons.math3.special;
 
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.util.ContinuedFraction;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.util.ContinuedFraction;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This is a utility class that provides computation methods related to the

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/package-info.java Tue Feb 14 16:17:55 2012
@@ -17,4 +17,4 @@
 /**
  * Implementations of special functions such as Beta and Gamma.
  */
-package org.apache.commons.math.special;
+package org.apache.commons.math3.special;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/Frequency.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/Frequency.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/Frequency.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/Frequency.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat;
+package org.apache.commons.math3.stat;
 
 import java.io.Serializable;
 import java.text.NumberFormat;
@@ -22,8 +22,8 @@ import java.util.Iterator;
 import java.util.Comparator;
 import java.util.TreeMap;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Maintains a frequency distribution.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/StatUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/StatUtils.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/Cluster.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/Cluster.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.clustering;
+package org.apache.commons.math3.stat.clustering;
 
 import java.io.Serializable;
 import java.util.ArrayList;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/Clusterable.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/Clusterable.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/Clusterable.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/Clusterable.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.clustering;
+package org.apache.commons.math3.stat.clustering;
 
 import java.util.Collection;
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/EuclideanIntegerPoint.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/EuclideanIntegerPoint.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/EuclideanIntegerPoint.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/EuclideanIntegerPoint.java Tue Feb 14 16:17:55 2012
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.clustering;
+package org.apache.commons.math3.stat.clustering;
 
 import java.io.Serializable;
 import java.util.Collection;
 
-import org.apache.commons.math.util.MathArrays;
+import org.apache.commons.math3.util.MathArrays;
 
 /**
  * A simple implementation of {@link Clusterable} for points with integer coordinates.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/KMeansPlusPlusClusterer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/KMeansPlusPlusClusterer.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/KMeansPlusPlusClusterer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/KMeansPlusPlusClusterer.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.clustering;
+package org.apache.commons.math3.stat.clustering;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -23,12 +23,12 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Random;
 
-import org.apache.commons.math.exception.ConvergenceException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.descriptive.moment.Variance;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.ConvergenceException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.descriptive.moment.Variance;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Clustering algorithm based on David Arthur and Sergei Vassilvitski k-means++ algorithm.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/package-info.java Tue Feb 14 16:17:55 2012
@@ -17,4 +17,4 @@
 /**
  * Clustering algorithms
  */
-package org.apache.commons.math.stat.clustering;
+package org.apache.commons.math3.stat.clustering;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/Covariance.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/Covariance.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/Covariance.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/Covariance.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.correlation;
+package org.apache.commons.math3.stat.correlation;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.linear.RealMatrix;
-import org.apache.commons.math.linear.BlockRealMatrix;
-import org.apache.commons.math.stat.descriptive.moment.Mean;
-import org.apache.commons.math.stat.descriptive.moment.Variance;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math3.linear.BlockRealMatrix;
+import org.apache.commons.math3.stat.descriptive.moment.Mean;
+import org.apache.commons.math3.stat.descriptive.moment.Variance;
 
 /**
  * Computes covariances for pairs of arrays or columns of a matrix.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/PearsonsCorrelation.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/PearsonsCorrelation.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/PearsonsCorrelation.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/PearsonsCorrelation.java Tue Feb 14 16:17:55 2012
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.correlation;
+package org.apache.commons.math3.stat.correlation;
 
-import org.apache.commons.math.distribution.TDistribution;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.linear.RealMatrix;
-import org.apache.commons.math.linear.BlockRealMatrix;
-import org.apache.commons.math.stat.regression.SimpleRegression;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.distribution.TDistribution;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math3.linear.BlockRealMatrix;
+import org.apache.commons.math3.stat.regression.SimpleRegression;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * Computes Pearson's product-moment correlation coefficients for pairs of arrays
@@ -157,7 +157,7 @@ public class PearsonsCorrelation {
      * <i>significance</i> of the corresponding correlation coefficients.</p>
      *
      * @return matrix of p-values
-     * @throws org.apache.commons.math.exception.MaxCountExceededException
+     * @throws org.apache.commons.math3.exception.MaxCountExceededException
      * if an error occurs estimating probabilities
      */
     public RealMatrix getCorrelationPValues() {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/SpearmansCorrelation.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/SpearmansCorrelation.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/SpearmansCorrelation.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/SpearmansCorrelation.java Tue Feb 14 16:17:55 2012
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.correlation;
+package org.apache.commons.math3.stat.correlation;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.linear.BlockRealMatrix;
-import org.apache.commons.math.linear.RealMatrix;
-import org.apache.commons.math.stat.ranking.NaturalRanking;
-import org.apache.commons.math.stat.ranking.RankingAlgorithm;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.linear.BlockRealMatrix;
+import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math3.stat.ranking.NaturalRanking;
+import org.apache.commons.math3.stat.ranking.RankingAlgorithm;
 
 /**
  * <p>Spearman's rank correlation. This implementation performs a rank

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/StorelessBivariateCovariance.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/StorelessBivariateCovariance.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/StorelessBivariateCovariance.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/StorelessBivariateCovariance.java Tue Feb 14 16:17:55 2012
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.correlation;
+package org.apache.commons.math3.stat.correlation;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Bivariate Covariance implementation that does not require input data to be

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/StorelessCovariance.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/StorelessCovariance.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/StorelessCovariance.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/StorelessCovariance.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.correlation;
+package org.apache.commons.math3.stat.correlation;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathUnsupportedOperationException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.linear.Array2DRowRealMatrix;
-import org.apache.commons.math.linear.RealMatrix;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathUnsupportedOperationException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.linear.Array2DRowRealMatrix;
+import org.apache.commons.math3.linear.RealMatrix;
 
 /**
  * Covariance implementation that does not require input data to be

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/correlation/package-info.java Tue Feb 14 16:17:55 2012
@@ -19,4 +19,4 @@
  *        Correlations/Covariance computations.
  *
  */
-package org.apache.commons.math.stat.correlation;
+package org.apache.commons.math3.stat.correlation;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AbstractStorelessUnivariateStatistic.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AbstractStorelessUnivariateStatistic.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AbstractStorelessUnivariateStatistic.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AbstractStorelessUnivariateStatistic.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.util.MathUtils;
-import org.apache.commons.math.util.Precision;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math3.util.Precision;
 
 /**
  *
@@ -52,7 +52,7 @@ public abstract class AbstractStorelessU
      * If the array is null, an IllegalArgumentException is thrown.</p>
      * @param values input array
      * @return the value of the statistic applied to the input array
-     * @see org.apache.commons.math.stat.descriptive.UnivariateStatistic#evaluate(double[])
+     * @see org.apache.commons.math3.stat.descriptive.UnivariateStatistic#evaluate(double[])
      */
     @Override
     public double evaluate(final double[] values) {
@@ -81,7 +81,7 @@ public abstract class AbstractStorelessU
      * @param begin the index of the first element to include
      * @param length the number of elements to include
      * @return the value of the statistic applied to the included array entries
-     * @see org.apache.commons.math.stat.descriptive.UnivariateStatistic#evaluate(double[], int, int)
+     * @see org.apache.commons.math3.stat.descriptive.UnivariateStatistic#evaluate(double[], int, int)
      */
     @Override
     public double evaluate(final double[] values, final int begin, final int length) {
@@ -121,7 +121,7 @@ public abstract class AbstractStorelessU
      *
      * @param values values to add
      * @throws IllegalArgumentException if values is null
-     * @see org.apache.commons.math.stat.descriptive.StorelessUnivariateStatistic#incrementAll(double[])
+     * @see org.apache.commons.math3.stat.descriptive.StorelessUnivariateStatistic#incrementAll(double[])
      */
     public void incrementAll(double[] values) {
         if (values == null) {
@@ -140,7 +140,7 @@ public abstract class AbstractStorelessU
      * @param begin   index of the first array element to add
      * @param length  number of array elements to add
      * @throws IllegalArgumentException if values is null
-     * @see org.apache.commons.math.stat.descriptive.StorelessUnivariateStatistic#incrementAll(double[], int, int)
+     * @see org.apache.commons.math3.stat.descriptive.StorelessUnivariateStatistic#incrementAll(double[], int, int)
      */
     public void incrementAll(double[] values, int begin, int length) {
         if (test(values, begin, length)) {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AbstractUnivariateStatistic.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AbstractUnivariateStatistic.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AbstractUnivariateStatistic.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AbstractUnivariateStatistic.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.NotPositiveException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.NotPositiveException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * Abstract base class for all implementations of the

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AggregateSummaryStatistics.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AggregateSummaryStatistics.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AggregateSummaryStatistics.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/AggregateSummaryStatistics.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
 import java.io.Serializable;
 import java.util.Collection;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/DescriptiveStatistics.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/DescriptiveStatistics.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/DescriptiveStatistics.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/DescriptiveStatistics.java Tue Feb 14 16:17:55 2012
@@ -14,29 +14,29 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
 import java.io.Serializable;
 import java.lang.reflect.InvocationTargetException;
 import java.util.Arrays;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.descriptive.moment.GeometricMean;
-import org.apache.commons.math.stat.descriptive.moment.Kurtosis;
-import org.apache.commons.math.stat.descriptive.moment.Mean;
-import org.apache.commons.math.stat.descriptive.moment.Skewness;
-import org.apache.commons.math.stat.descriptive.moment.Variance;
-import org.apache.commons.math.stat.descriptive.rank.Max;
-import org.apache.commons.math.stat.descriptive.rank.Min;
-import org.apache.commons.math.stat.descriptive.rank.Percentile;
-import org.apache.commons.math.stat.descriptive.summary.Sum;
-import org.apache.commons.math.stat.descriptive.summary.SumOfSquares;
-import org.apache.commons.math.util.MathUtils;
-import org.apache.commons.math.util.ResizableDoubleArray;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.descriptive.moment.GeometricMean;
+import org.apache.commons.math3.stat.descriptive.moment.Kurtosis;
+import org.apache.commons.math3.stat.descriptive.moment.Mean;
+import org.apache.commons.math3.stat.descriptive.moment.Skewness;
+import org.apache.commons.math3.stat.descriptive.moment.Variance;
+import org.apache.commons.math3.stat.descriptive.rank.Max;
+import org.apache.commons.math3.stat.descriptive.rank.Min;
+import org.apache.commons.math3.stat.descriptive.rank.Percentile;
+import org.apache.commons.math3.stat.descriptive.summary.Sum;
+import org.apache.commons.math3.stat.descriptive.summary.SumOfSquares;
+import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math3.util.ResizableDoubleArray;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/MultivariateSummaryStatistics.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/MultivariateSummaryStatistics.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/MultivariateSummaryStatistics.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/MultivariateSummaryStatistics.java Tue Feb 14 16:17:55 2012
@@ -14,27 +14,27 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
 import java.io.Serializable;
 import java.util.Arrays;
 
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.linear.RealMatrix;
-import org.apache.commons.math.stat.descriptive.moment.GeometricMean;
-import org.apache.commons.math.stat.descriptive.moment.Mean;
-import org.apache.commons.math.stat.descriptive.moment.VectorialCovariance;
-import org.apache.commons.math.stat.descriptive.rank.Max;
-import org.apache.commons.math.stat.descriptive.rank.Min;
-import org.apache.commons.math.stat.descriptive.summary.Sum;
-import org.apache.commons.math.stat.descriptive.summary.SumOfLogs;
-import org.apache.commons.math.stat.descriptive.summary.SumOfSquares;
-import org.apache.commons.math.util.MathUtils;
-import org.apache.commons.math.util.MathArrays;
-import org.apache.commons.math.util.Precision;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.linear.RealMatrix;
+import org.apache.commons.math3.stat.descriptive.moment.GeometricMean;
+import org.apache.commons.math3.stat.descriptive.moment.Mean;
+import org.apache.commons.math3.stat.descriptive.moment.VectorialCovariance;
+import org.apache.commons.math3.stat.descriptive.rank.Max;
+import org.apache.commons.math3.stat.descriptive.rank.Min;
+import org.apache.commons.math3.stat.descriptive.summary.Sum;
+import org.apache.commons.math3.stat.descriptive.summary.SumOfLogs;
+import org.apache.commons.math3.stat.descriptive.summary.SumOfSquares;
+import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math3.util.MathArrays;
+import org.apache.commons.math3.util.Precision;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * <p>Computes summary statistics for a stream of n-tuples added using the

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalMultivariateSummary.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalMultivariateSummary.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalMultivariateSummary.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalMultivariateSummary.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
-import org.apache.commons.math.linear.RealMatrix;
+import org.apache.commons.math3.linear.RealMatrix;
 
 /**
  *  Reporting interface for basic multivariate statistics.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalSummary.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalSummary.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalSummary.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalSummary.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
 /**
  *  Reporting interface for basic univariate statistics.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalSummaryValues.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalSummaryValues.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalSummaryValues.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StatisticalSummaryValues.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
-import org.apache.commons.math.util.Precision;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math3.util.Precision;
 
 /**
  *  Value object representing the results of a univariate statistical summary.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StorelessUnivariateStatistic.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StorelessUnivariateStatistic.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StorelessUnivariateStatistic.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/StorelessUnivariateStatistic.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
 /**
  * Extends the definition of {@link UnivariateStatistic} with

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SummaryStatistics.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SummaryStatistics.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SummaryStatistics.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SummaryStatistics.java Tue Feb 14 16:17:55 2012
@@ -14,25 +14,25 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.descriptive.moment.GeometricMean;
-import org.apache.commons.math.stat.descriptive.moment.Mean;
-import org.apache.commons.math.stat.descriptive.moment.SecondMoment;
-import org.apache.commons.math.stat.descriptive.moment.Variance;
-import org.apache.commons.math.stat.descriptive.rank.Max;
-import org.apache.commons.math.stat.descriptive.rank.Min;
-import org.apache.commons.math.stat.descriptive.summary.Sum;
-import org.apache.commons.math.stat.descriptive.summary.SumOfLogs;
-import org.apache.commons.math.stat.descriptive.summary.SumOfSquares;
-import org.apache.commons.math.util.MathUtils;
-import org.apache.commons.math.util.Precision;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.descriptive.moment.GeometricMean;
+import org.apache.commons.math3.stat.descriptive.moment.Mean;
+import org.apache.commons.math3.stat.descriptive.moment.SecondMoment;
+import org.apache.commons.math3.stat.descriptive.moment.Variance;
+import org.apache.commons.math3.stat.descriptive.rank.Max;
+import org.apache.commons.math3.stat.descriptive.rank.Min;
+import org.apache.commons.math3.stat.descriptive.summary.Sum;
+import org.apache.commons.math3.stat.descriptive.summary.SumOfLogs;
+import org.apache.commons.math3.stat.descriptive.summary.SumOfSquares;
+import org.apache.commons.math3.util.MathUtils;
+import org.apache.commons.math3.util.Precision;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * <p>

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedDescriptiveStatistics.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedDescriptiveStatistics.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedDescriptiveStatistics.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedDescriptiveStatistics.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Implementation of
- * {@link org.apache.commons.math.stat.descriptive.DescriptiveStatistics} that
+ * {@link org.apache.commons.math3.stat.descriptive.DescriptiveStatistics} that
  * is safe to use in a multithreaded environment.  Multiple threads can safely
  * operate on a single instance without causing runtime exceptions due to race
  * conditions.  In effect, this implementation makes modification and access

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedMultivariateSummaryStatistics.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedMultivariateSummaryStatistics.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedMultivariateSummaryStatistics.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedMultivariateSummaryStatistics.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
-import org.apache.commons.math.linear.RealMatrix;
+import org.apache.commons.math3.linear.RealMatrix;
 
 /**
  * Implementation of
- * {@link org.apache.commons.math.stat.descriptive.MultivariateSummaryStatistics} that
+ * {@link org.apache.commons.math3.stat.descriptive.MultivariateSummaryStatistics} that
  * is safe to use in a multithreaded environment.  Multiple threads can safely
  * operate on a single instance without causing runtime exceptions due to race
  * conditions.  In effect, this implementation makes modification and access

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedSummaryStatistics.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedSummaryStatistics.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedSummaryStatistics.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/SynchronizedSummaryStatistics.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Implementation of
- * {@link org.apache.commons.math.stat.descriptive.SummaryStatistics} that
+ * {@link org.apache.commons.math3.stat.descriptive.SummaryStatistics} that
  * is safe to use in a multithreaded environment.  Multiple threads can safely
  * operate on a single instance without causing runtime exceptions due to race
  * conditions.  In effect, this implementation makes modification and access

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/UnivariateStatistic.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/UnivariateStatistic.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/UnivariateStatistic.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/UnivariateStatistic.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/WeightedEvaluation.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/WeightedEvaluation.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/WeightedEvaluation.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/WeightedEvaluation.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;
 
 /**
  * Weighted evaluation for statistics.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/FirstMoment.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/FirstMoment.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/FirstMoment.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/FirstMoment.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Computes the first moment (arithmetic mean).  Uses the definitional formula:

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/FourthMoment.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/FourthMoment.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/FourthMoment.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/FourthMoment.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Computes a statistic related to the Fourth Central Moment.  Specifically,

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/GeometricMean.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/GeometricMean.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/GeometricMean.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/GeometricMean.java Tue Feb 14 16:17:55 2012
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.stat.descriptive.StorelessUnivariateStatistic;
-import org.apache.commons.math.stat.descriptive.summary.SumOfLogs;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.stat.descriptive.StorelessUnivariateStatistic;
+import org.apache.commons.math3.stat.descriptive.summary.SumOfLogs;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Returns the <a href="http://www.xycoon.com/geometric_mean.htm">

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Kurtosis.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Kurtosis.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Kurtosis.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Kurtosis.java Tue Feb 14 16:17:55 2012
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Mean.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Mean.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Mean.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Mean.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.stat.descriptive.WeightedEvaluation;
-import org.apache.commons.math.stat.descriptive.summary.Sum;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.stat.descriptive.WeightedEvaluation;
+import org.apache.commons.math3.stat.descriptive.summary.Sum;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * <p>Computes the arithmetic mean of a set of values. Uses the definitional

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/SecondMoment.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/SecondMoment.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/SecondMoment.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/SecondMoment.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Computes a statistic related to the Second Central Moment.  Specifically,

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/SemiVariance.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/SemiVariance.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/SemiVariance.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/SemiVariance.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.descriptive.AbstractUnivariateStatistic;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.descriptive.AbstractUnivariateStatistic;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * <p>Computes the semivariance of a set of values with respect to a given cutoff value.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Skewness.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Skewness.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Skewness.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Skewness.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Computes the skewness of the available values.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/StandardDeviation.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/StandardDeviation.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/StandardDeviation.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/StandardDeviation.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Computes the sample standard deviation.  The standard deviation

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/ThirdMoment.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/ThirdMoment.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/ThirdMoment.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/ThirdMoment.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.util.MathUtils;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Variance.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Variance.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Variance.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/Variance.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.descriptive.WeightedEvaluation;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.descriptive.WeightedEvaluation;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Computes the variance of the available values.  By default, the unbiased

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/VectorialCovariance.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/VectorialCovariance.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/VectorialCovariance.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/VectorialCovariance.java Tue Feb 14 16:17:55 2012
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 import java.util.Arrays;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.linear.MatrixUtils;
-import org.apache.commons.math.linear.RealMatrix;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.linear.MatrixUtils;
+import org.apache.commons.math3.linear.RealMatrix;
 
 /**
  * Returns the covariance matrix of the available vectors.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/VectorialMean.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/VectorialMean.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/VectorialMean.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/VectorialMean.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;
 
 import java.io.Serializable;
 import java.util.Arrays;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
 
 /**
  * Returns the arithmetic mean of the available vectors.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/moment/package-info.java Tue Feb 14 16:17:55 2012
@@ -17,4 +17,4 @@
 /**
  * Summary statistics based on moments.
  */
-package org.apache.commons.math.stat.descriptive.moment;
+package org.apache.commons.math3.stat.descriptive.moment;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/package-info.java Tue Feb 14 16:17:55 2012
@@ -41,4 +41,4 @@
  *        </code>
  *
  */
-package org.apache.commons.math.stat.descriptive;
+package org.apache.commons.math3.stat.descriptive;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Max.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Max.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Max.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Max.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.rank;
+package org.apache.commons.math3.stat.descriptive.rank;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.stat.descriptive.AbstractStorelessUnivariateStatistic;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.stat.descriptive.AbstractStorelessUnivariateStatistic;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * Returns the maximum of the available values.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Median.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Median.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Median.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/descriptive/rank/Median.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat.descriptive.rank;
+package org.apache.commons.math3.stat.descriptive.rank;
 
 import java.io.Serializable;
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/random/package-info.java Tue Feb 14 16:17:55 2012
@@ -20,19 +20,19 @@
  *      <p>Commons-math provides a few pseudo random number generators. The top level interface is RandomGenerator.
  *      It is implemented by three classes:
  *      <ul>
- *        <li>{@link org.apache.commons.math.random.JDKRandomGenerator JDKRandomGenerator}
+ *        <li>{@link org.apache.commons.math3.random.JDKRandomGenerator JDKRandomGenerator}
  *            that extends the JDK provided generator</li>
  *        <li>AbstractRandomGenerator as a helper for users generators</li>
  *        <li>BitStreamGenerator which is an abstract class for several generators and
  *            which in turn is extended by:
  *            <ul>
  *              <li>{@link org.apache.commons.math.random.MersenneTwister MersenneTwister}</li>
  *              <li>{@link org.apache.commons.math.random.Well512a Well512a}</li>
  *              <li>{@link org.apache.commons.math.random.Well1024a Well1024a}</li>
  *              <li>{@link org.apache.commons.math.random.Well19937a Well19937a}</li>
  *              <li>{@link org.apache.commons.math.random.Well19937c Well19937c}</li>
  *              <li>{@link org.apache.commons.math.random.Well44497a Well44497a}</li>
  *              <li>{@link org.apache.commons.math.random.Well44497b Well44497b}</li>
  *            </ul>
  *          </li>
  *        </ul>
@@ -103,21 +103,21 @@
  *        <table border="1" align="center">
  *          <tr BGCOLOR="#CCCCFF"><td colspan="2"><font size="+2">Example of performances</font></td></tr>
  *          <tr BGCOLOR="#EEEEFF"><font size="+1"><td>Name</td><td>generation rate (relative to MersenneTwister)</td></font></tr>
  *          <tr><td>{@link org.apache.commons.math.random.MersenneTwister MersenneTwister}</td><td>1</td></tr>
  *          <tr><td>{@link org.apache.commons.math.random.JDKRandomGenerator JDKRandomGenerator}</td><td>between 0.96 and 1.16</td></tr>
  *          <tr><td>{@link org.apache.commons.math.random.Well512a Well512a}</td><td>between 0.85 and 0.88</td></tr>
  *          <tr><td>{@link org.apache.commons.math.random.Well1024a Well1024a}</td><td>between 0.63 and 0.73</td></tr>
  *          <tr><td>{@link org.apache.commons.math.random.Well19937a Well19937a}</td><td>between 0.70 and 0.71</td></tr>
  *          <tr><td>{@link org.apache.commons.math.random.Well19937c Well19937c}</td><td>between 0.57 and 0.71</td></tr>
  *          <tr><td>{@link org.apache.commons.math.random.Well44497a Well44497a}</td><td>between 0.69 and 0.71</td></tr>
  *          <tr><td>{@link org.apache.commons.math.random.Well44497b Well44497b}</td><td>between 0.65 and 0.71</td></tr>
  *        </table>
  *      </p>
  *
  *      <p>
  *      So for most simulation problems, the better generators like {@link
  *      org.apache.commons.math.random.Well19937c Well19937c} and {@link
  *      org.apache.commons.math.random.Well44497b Well44497b} are probably very good choices.
  *      </p>
  *
  *      <p>
@@ -129,4 +129,4 @@
  *
  *
  */
-package org.apache.commons.math.random;
+package org.apache.commons.math3.random;
@@ -20,19 +20,19 @@
  *            which in turn is extended by:
  *            <ul>
- *              <li>{@link org.apache.commons.math.random.MersenneTwister MersenneTwister}</li>
- *              <li>{@link org.apache.commons.math.random.Well512a Well512a}</li>
- *              <li>{@link org.apache.commons.math.random.Well1024a Well1024a}</li>
- *              <li>{@link org.apache.commons.math.random.Well19937a Well19937a}</li>
- *              <li>{@link org.apache.commons.math.random.Well19937c Well19937c}</li>
- *              <li>{@link org.apache.commons.math.random.Well44497a Well44497a}</li>
- *              <li>{@link org.apache.commons.math.random.Well44497b Well44497b}</li>
+ *              <li>{@link org.apache.commons.math3.random.MersenneTwister MersenneTwister}</li>
+ *              <li>{@link org.apache.commons.math3.random.Well512a Well512a}</li>
+ *              <li>{@link org.apache.commons.math3.random.Well1024a Well1024a}</li>
+ *              <li>{@link org.apache.commons.math3.random.Well19937a Well19937a}</li>
+ *              <li>{@link org.apache.commons.math3.random.Well19937c Well19937c}</li>
+ *              <li>{@link org.apache.commons.math3.random.Well44497a Well44497a}</li>
+ *              <li>{@link org.apache.commons.math3.random.Well44497b Well44497b}</li>
  *            </ul>
  *          </li>
@@ -103,21 +103,21 @@
  *          <tr BGCOLOR="#CCCCFF"><td colspan="2"><font size="+2">Example of performances</font></td></tr>
  *          <tr BGCOLOR="#EEEEFF"><font size="+1"><td>Name</td><td>generation rate (relative to MersenneTwister)</td></font></tr>
- *          <tr><td>{@link org.apache.commons.math.random.MersenneTwister MersenneTwister}</td><td>1</td></tr>
- *          <tr><td>{@link org.apache.commons.math.random.JDKRandomGenerator JDKRandomGenerator}</td><td>between 0.96 and 1.16</td></tr>
- *          <tr><td>{@link org.apache.commons.math.random.Well512a Well512a}</td><td>between 0.85 and 0.88</td></tr>
- *          <tr><td>{@link org.apache.commons.math.random.Well1024a Well1024a}</td><td>between 0.63 and 0.73</td></tr>
- *          <tr><td>{@link org.apache.commons.math.random.Well19937a Well19937a}</td><td>between 0.70 and 0.71</td></tr>
- *          <tr><td>{@link org.apache.commons.math.random.Well19937c Well19937c}</td><td>between 0.57 and 0.71</td></tr>
- *          <tr><td>{@link org.apache.commons.math.random.Well44497a Well44497a}</td><td>between 0.69 and 0.71</td></tr>
- *          <tr><td>{@link org.apache.commons.math.random.Well44497b Well44497b}</td><td>between 0.65 and 0.71</td></tr>
+ *          <tr><td>{@link org.apache.commons.math3.random.MersenneTwister MersenneTwister}</td><td>1</td></tr>
+ *          <tr><td>{@link org.apache.commons.math3.random.JDKRandomGenerator JDKRandomGenerator}</td><td>between 0.96 and 1.16</td></tr>
+ *          <tr><td>{@link org.apache.commons.math3.random.Well512a Well512a}</td><td>between 0.85 and 0.88</td></tr>
+ *          <tr><td>{@link org.apache.commons.math3.random.Well1024a Well1024a}</td><td>between 0.63 and 0.73</td></tr>
+ *          <tr><td>{@link org.apache.commons.math3.random.Well19937a Well19937a}</td><td>between 0.70 and 0.71</td></tr>
+ *          <tr><td>{@link org.apache.commons.math3.random.Well19937c Well19937c}</td><td>between 0.57 and 0.71</td></tr>
+ *          <tr><td>{@link org.apache.commons.math3.random.Well44497a Well44497a}</td><td>between 0.69 and 0.71</td></tr>
+ *          <tr><td>{@link org.apache.commons.math3.random.Well44497b Well44497b}</td><td>between 0.65 and 0.71</td></tr>
  *        </table>
  *      </p>
@@ -103,21 +103,21 @@
  *      <p>
  *      So for most simulation problems, the better generators like {@link
- *      org.apache.commons.math.random.Well19937c Well19937c} and {@link
- *      org.apache.commons.math.random.Well44497b Well44497b} are probably very good choices.
+ *      org.apache.commons.math3.random.Well19937c Well19937c} and {@link
+ *      org.apache.commons.math3.random.Well44497b Well44497b} are probably very good choices.
  *      </p>
  *

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Beta.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/special/Beta.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/StatUtils.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/StatUtils.java Tue Feb 14 16:17:55 2012
@@ -14,24 +14,24 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.stat;
+package org.apache.commons.math3.stat;
 
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.NoDataException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.stat.descriptive.DescriptiveStatistics;
-import org.apache.commons.math.stat.descriptive.UnivariateStatistic;
-import org.apache.commons.math.stat.descriptive.moment.GeometricMean;
-import org.apache.commons.math.stat.descriptive.moment.Mean;
-import org.apache.commons.math.stat.descriptive.moment.Variance;
-import org.apache.commons.math.stat.descriptive.rank.Max;
-import org.apache.commons.math.stat.descriptive.rank.Min;
-import org.apache.commons.math.stat.descriptive.rank.Percentile;
-import org.apache.commons.math.stat.descriptive.summary.Product;
-import org.apache.commons.math.stat.descriptive.summary.Sum;
-import org.apache.commons.math.stat.descriptive.summary.SumOfLogs;
-import org.apache.commons.math.stat.descriptive.summary.SumOfSquares;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.stat.descriptive.DescriptiveStatistics;
+import org.apache.commons.math3.stat.descriptive.UnivariateStatistic;
+import org.apache.commons.math3.stat.descriptive.moment.GeometricMean;
+import org.apache.commons.math3.stat.descriptive.moment.Mean;
+import org.apache.commons.math3.stat.descriptive.moment.Variance;
+import org.apache.commons.math3.stat.descriptive.rank.Max;
+import org.apache.commons.math3.stat.descriptive.rank.Min;
+import org.apache.commons.math3.stat.descriptive.rank.Percentile;
+import org.apache.commons.math3.stat.descriptive.summary.Product;
+import org.apache.commons.math3.stat.descriptive.summary.Sum;
+import org.apache.commons.math3.stat.descriptive.summary.SumOfLogs;
+import org.apache.commons.math3.stat.descriptive.summary.SumOfSquares;
 
 /**
  * StatUtils provides static methods for computing statistics based on data
@@ -185,7 +185,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.summary.SumOfLogs}.
+     * See {@link org.apache.commons.math3.stat.descriptive.summary.SumOfLogs}.
      * </p>
      *
      * @param values the input array
@@ -204,7 +204,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.summary.SumOfLogs}.
+     * See {@link org.apache.commons.math3.stat.descriptive.summary.SumOfLogs}.
      * </p>
      *
      * @param values the input array
@@ -226,7 +226,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.moment.Mean} for
      * details on the computing algorithm.</p>
      *
      * @param values the input array
@@ -244,7 +244,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.moment.Mean} for
      * details on the computing algorithm.</p>
      *
      * @param values the input array
@@ -265,7 +265,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.GeometricMean}
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.GeometricMean}
      * for details on the computing algorithm.</p>
      *
      * @param values the input array
@@ -283,7 +283,7 @@ public final class StatUtils {
      * <p>
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.GeometricMean}
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.GeometricMean}
      * for details on the computing algorithm.</p>
      *
      * @param values the input array
@@ -307,7 +307,7 @@ public final class StatUtils {
      * the denominator).  Use {@link #populationVariance(double[])} for the non-bias-corrected
      * population variance.</p>
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * Returns 0 for a single-value (i.e. length = 1) sample.</p>
@@ -331,7 +331,7 @@ public final class StatUtils {
      * the denominator).  Use {@link #populationVariance(double[], int, int)} for the non-bias-corrected
      * population variance.</p>
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * Returns 0 for a single-value (i.e. length = 1) sample.</p>
@@ -360,7 +360,7 @@ public final class StatUtils {
      * the denominator).  Use {@link #populationVariance(double[], double, int, int)} for the non-bias-corrected
      * population variance.</p>
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * The formula used assumes that the supplied mean value is the arithmetic
@@ -395,7 +395,7 @@ public final class StatUtils {
      * the denominator).  Use {@link #populationVariance(double[], double)} for the non-bias-corrected
      * population variance.</p>
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * The formula used assumes that the supplied mean value is the arithmetic
@@ -421,7 +421,7 @@ public final class StatUtils {
      * population variance</a> of the entries in the input array, or
      * <code>Double.NaN</code> if the array is empty.
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
      * details on the formula and computing algorithm.</p>
      * <p>
      * Returns 0 for a single-value (i.e. length = 1) sample.</p>
@@ -442,7 +442,7 @@ public final class StatUtils {
      * the input array, or <code>Double.NaN</code> if the designated subarray
      * is empty.
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * Returns 0 for a single-value (i.e. length = 1) sample.</p>
@@ -468,7 +468,7 @@ public final class StatUtils {
      * the input array, using the precomputed mean value.  Returns
      * <code>Double.NaN</code> if the designated subarray is empty.
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * The formula used assumes that the supplied mean value is the arithmetic
@@ -500,7 +500,7 @@ public final class StatUtils {
      * precomputed mean value.  Returns <code>Double.NaN</code> if the array
      * is empty.
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
      * The formula used assumes that the supplied mean value is the arithmetic
@@ -631,7 +631,7 @@ public final class StatUtils {
      * and less than or equal to 100)</li>
      * </ul></p>
      * <p>
      * See {@link org.apache.commons.math.stat.descriptive.rank.Percentile} for
      * a description of the percentile estimation algorithm used.</p>
      *
      * @param values input array of values
@@ -660,7 +660,7 @@ public final class StatUtils {
      * and less than or equal to 100)</li>
      * </ul></p>
      * <p>
       * See {@link org.apache.commons.math.stat.descriptive.rank.Percentile} for
       * a description of the percentile estimation algorithm used.</p>
      *
      * @param values array of input values
@@ -226,7 +226,7 @@ public final class StatUtils {
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.Mean} for
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.Mean} for
      * details on the computing algorithm.</p>
      *
@@ -244,7 +244,7 @@ public final class StatUtils {
      * Throws <code>IllegalArgumentException</code> if the array is null.</p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.Mean} for
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.Mean} for
      * details on the computing algorithm.</p>
      *
@@ -307,7 +307,7 @@ public final class StatUtils {
      * population variance.</p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -331,7 +331,7 @@ public final class StatUtils {
      * population variance.</p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -360,7 +360,7 @@ public final class StatUtils {
      * population variance.</p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -395,7 +395,7 @@ public final class StatUtils {
      * population variance.</p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -421,7 +421,7 @@ public final class StatUtils {
      * <code>Double.NaN</code> if the array is empty.
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the formula and computing algorithm.</p>
      * <p>
@@ -442,7 +442,7 @@ public final class StatUtils {
      * is empty.
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -468,7 +468,7 @@ public final class StatUtils {
      * <code>Double.NaN</code> if the designated subarray is empty.
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -500,7 +500,7 @@ public final class StatUtils {
      * is empty.
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.moment.Variance} for
+     * See {@link org.apache.commons.math3.stat.descriptive.moment.Variance} for
      * details on the computing algorithm.</p>
      * <p>
@@ -631,7 +631,7 @@ public final class StatUtils {
      * </ul></p>
      * <p>
-     * See {@link org.apache.commons.math.stat.descriptive.rank.Percentile} for
+     * See {@link org.apache.commons.math3.stat.descriptive.rank.Percentile} for
      * a description of the percentile estimation algorithm used.</p>
      *
@@ -660,7 +660,7 @@ public final class StatUtils {
      * </ul></p>
      * <p>
-      * See {@link org.apache.commons.math.stat.descriptive.rank.Percentile} for
+      * See {@link org.apache.commons.math3.stat.descriptive.rank.Percentile} for
       * a description of the percentile estimation algorithm used.</p>
      *

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/Cluster.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/stat/clustering/Cluster.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================